@@ -4,11 +4,11 @@ use warnings;
 
 use Test2::IPC;
 
-our $VERSION = '0.000095'; # TRIAL
+our $VERSION = '0.000098'; # TRIAL
 
 our @CARP_NOT = qw/Test2::Util::HashBase/;
 
-use Carp qw/croak cluck/;
+use Carp qw/croak cluck confess/;
 use Test2::Util qw/get_tid CAN_THREAD CAN_FORK/;
 use Scalar::Util qw/blessed/;
 use List::Util qw/first/;
@@ -52,7 +52,7 @@ sub init {
     croak "'name' is a required attribute"
         unless $self->{+NAME};
 
-    $self->{+SEND_TO} ||= Test2::API::test2_stack()->top;
+    my $to = $self->{+SEND_TO} ||= Test2::API::test2_stack()->top;
 
     $self->{+STACK} = [@STACK];
     $_->{+_IN_USE}++ for reverse @STACK;
@@ -71,15 +71,18 @@ sub init {
         my $args = delete $self->{hub_init_args} || {};
         my $hub = Test2::AsyncSubtest::Hub->new(
             %$args,
-            ipc => $ipc,
-            nested => 1,
+            ipc       => $ipc,
+            nested    => $to->nested + 1,
+            buffered  => 1,
             formatter => $formatter,
         );
         $self->{+HUB} = $hub;
     }
 
     $self->{+TRACE} ||= Test2::Util::Trace->new(
-        frame => [caller(1)],
+        frame    => [caller(1)],
+        buffered => $to->buffered,
+        nested   => $to->nested,
     );
 
     my $hub = $self->{+HUB};
@@ -112,9 +115,15 @@ sub _pre_filter {
 
 sub context {
     my $self = shift;
+
+    my $send_to = $self->{+SEND_TO};
+
+    confess "Attempt to close AsyncSubtest when original parent hub (a non async-subtest?) has ended"
+        if $send_to->ended;
+
     return Test2::API::Context->new(
         trace => $self->{+TRACE},
-        hub   => $self->{+SEND_TO},
+        hub   => $send_to,
     );
 }
 
@@ -746,7 +755,7 @@ C<< $ast->run_fork >>, or C<< $ast->run_thread >>.
 =head1 SOURCE
 
 The source code repository for Test2-AsyncSubtest can be found at
-F<http://github.com/Test-More/Test2-AsyncSubtest/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
