@@ -2,7 +2,7 @@ package Test2::Manual::Anatomy;
 use strict;
 use warnings;
 
-our $VERSION = '0.000095'; # TRIAL
+our $VERSION = '0.000098'; # TRIAL
 
 1;
 
@@ -29,7 +29,8 @@ The L<Test2::Manual::Anatomy::Event> document explains the internals of events.
 
 =head1 THE CONTEXT
 
-COMING SOON.
+The L<Test2::Manual::Anatomy::Context> document explains how the
+L<Test2::API::Context> object works.
 
 =head1 THE API AND THE API INSTANCE
 
@@ -54,7 +55,7 @@ L<Test2::Manual> - Primary index of the manual.
 =head1 SOURCE
 
 The source code repository for Test2-Manual can be found at
-F<http://github.com/Test-More/Test2-Manual/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
