@@ -3,7 +3,7 @@ package Test2::Tools::GenTemp;
 use strict;
 use warnings;
 
-our $VERSION = '0.000095'; # TRIAL
+our $VERSION = '0.000098'; # TRIAL
 
 use File::Temp qw/tempdir/;
 use File::Spec;
@@ -95,7 +95,7 @@ C<< -tempdir => [...] >> argument.
 =head1 SOURCE
 
 The source code repository for Test2-Suite can be found at
-F<http://github.com/Test-More/Test2-Suite/>.
+F<https://github.com/Test-More/Test2-Suite/>.
 
 =head1 MAINTAINERS
 
